/* File......: $unlocktst.prg
*  Author....: cautere@innet.be
*  Date......: $Date... $
*  Revision..: $Revision$
*  Log file..: $Logfile$
*/

/* $DOC$
*  $FUNCNAME$
*    ISALLUNLOCKED()
*
*  $CATEGORY$
*    Database
*
*  $ONELINER$
*    Chech all (or some) workareas for any recordlock.
*
*  $SYNTAX$
*    ISALLUNLOCKED(nFirst, nLast)
*
*  $ARGUMENTS$
*    nFirst  : first workarea to check
*    nLast   : last workarea
*
*  $RETURNS$
*    0 if nothing is locked
*    first workarea with a record lock (or more locks)
*
*  $DESCRIPTION$
*    Check at a "neutral" place in your program (menu):
*      warns you for "forgotten" recordlocks (incorrect lock/unlock sequence).
*    Attention: only usefull for Clipper 5.2 : previous versions don't have
*       dbrlocklist().
*
*  $EXAMPLES$
*   if isallunlocked(1,10)  // check workarea 1...10
*     alert("still records locked")
*   endif
*
*  $SEEALSO$
*    RLOCK()  DBRLOCK()  UNLOCK  IS_LOCKED() DBRLOCKLIST()
*
*  $INCLUDE$
*
*  $END$
*/

#include "common.ch"

FUNCTION ISALLUNLOCKED(nFirst, nLast)
local i
local aLocked
local cAlias
DEFAULT nFirst  TO 1
DEFAULT nLast TO 255
for i := nFirst to nLast
  cAlias := alias(i)
  if !empty(cAlias)
    aLocked := (alias(i))->(dbrlocklist())
    if !empty(aLocked)
      return i
    endif
  endif
next
return 0

/* $DOC$
*
*  $FUNCNAME$
*    IS_LOCKED()
*
*  $CATEGORY$
*    Database
*
*  $SYNTAX$
*    IS_LOCKED([nRec])  -> lLocked
*
*  $ARGUMENTS$
*    nRec  = recordno
*
*  $RETURNS$
*    <lLocked>  := record locked
*           .T.         Record is locked
*           .F.         Record is not locked
*
*  $DESCRIPTION$
*        This function allows you to determine if the current
*        record in the selected workarea is locked.
*        Attention: Clipper 5.2 needed: uses DBRLOCKLIST()
*
*  $EXAMPLES$
*
*  $SEEALSO$
*    RLOCK()  DBRLOCK()  UNLOCK  ISALLUNLOCKED()  DBRLOCKLIST()
*  $INCLUDE$
*
*  $END$
*/

FUNCTION IS_LOCKED(nRec)
 DEFAULT nRec TO recno()
 return (ascan(dbrlocklist(), nRec) > 0)

